@@ -34,17 +34,22 @@ class Base(ABC):
             salida del procesamiento de la accion.
         """
 
+        errorCodeBk = None
+
         try:
             errorCodeBk = errorCode
             # Prevenir el paso de string como error
             errorCode = int(errorCode)
-        except:
+        except Exception:
             print(
-                'Ocurrio une error al realizar el CAST del error code: {}'.format(errorCodeBk))
+                'Ocurrio une error al realizar el CAST del error: {}'.format(
+                    errorCodeBk
+                )
+            )
             errorCode = -99
 
         # Regresar la respuesta con el formato correcto
-        if not errorWorker is None:
+        if errorWorker is not None:
             pass
 
         resp = {
@@ -70,7 +75,7 @@ class Base(ABC):
         # Retornar los datos
         return resp
 
-    def getParams(self, span, data, paramList):
+    def getParams(self, data, paramList):
         """
             Metodo para recuperar los datos segun la configuracion
             de los parametros.
@@ -78,13 +83,10 @@ class Base(ABC):
         # Parametros
         paramsInject = {}
 
-        log = {'event': 'input'}
-
         # Seleccion de parametros
         for i in paramList:
             if i == 'data':
                 paramsInject.update({i: data.get('data')})
-                log['data'] = data.get('data')
             elif i == 'filters':
                 data_params = self.__transformFilter(
                     getItemBy('metadata.filters', data))
@@ -92,22 +94,13 @@ class Base(ABC):
                 paramsInject.update({
                     i: data_params,
                 })
-                log['filters'] = data_params
             elif i == 'authorizacion':
                 paramsInject.update({i: data["headers"]["Authorizacion"]})
-                log['authorizacion'] = data["headers"]["Authorizacion"]
             elif i == 'uuid':
                 paramsInject.update({i: getItemBy('metadata.uuid', data)})
-                log['uuid'] = getItemBy('metadata.uuid', data)
             elif i == 'response':
-                if 'response' in data and 'data' in data['response'] and 'response' in data['response']['data']:
-                    paramsInject.update(
-                        {i: getItemBy('response.data.response', data)})
-                    log['response'] = getItemBy('response.data.response', data)
-                else:
-                    paramsInject.update({i: data.get('data')})
-                    log['response'] = data.get('data')
-        span.log_kv(log)
+                paramsInject.update(
+                    {i: getItemBy('response.data.response', data)})
 
         return paramsInject
 
