@@ -1,9 +1,6 @@
 import time
 import math
 import datetime
-import traceback
-from opentracing.ext import tags as ext_tags
-from .ErrorMs import ErrorMs
 from .Base import Base
 from .Util import getItemBy, verbAction
 
@@ -39,8 +36,10 @@ class Fork(Base):
         if getItemBy('metadata.data_inicial', data) is None:
             data['metadata']['data_inicial'] = data['data'].copy()
 
+        owner = getItemBy('metadata.owner', data)
+
         # Validar si es consecutivo o primer servicio
-        if self.Topico != getItemBy('metadata.owner', data) or len(self.___forks) < 1:
+        if self.Topico != owner or len(self.___forks) < 1:
             # Recuperar el siguiente
             nextFork = self.nextFork(getItemBy('metadata.owner', data))
 
@@ -55,7 +54,12 @@ class Fork(Base):
 
             if isError:
                 # Retornar el mensaje correcto
-                return self.formatResponse(data, None, self.getErrorCode(data), self.getErrorMeta(data))
+                return self.formatResponse(
+                    data,
+                    None,
+                    self.getErrorCode(data),
+                    self.getErrorMeta(data)
+                )
             elif nextFork is None:
                 # Parametros
                 paramsInject = self.getParams(span, data, params)
@@ -68,7 +72,9 @@ class Fork(Base):
             else:
                 row = self.getNextTopic(nextFork)
                 conf = self.___conf_forks.get(row.get('current'))
-                data['metadata']['original_method'] = data['metadata']['method']
+                method = data['metadata']['method']
+
+                data['metadata']['original_method'] = method
                 data['metadata']['method'] = verbAction(conf.get('action'))
 
                 resp = None
@@ -100,7 +106,8 @@ class Fork(Base):
             # Indicar que es una bifurcacion
             data['metadata']['bifurcacion'] = True
 
-            # Agregar el metodo que corresponde y se guarda una copia para usarla despues
+            # Agregar el metodo que corresponde y se
+            # guarda una copia para usarla despues
             data['metadata']['original_method'] = data['metadata']['method']
             data['metadata']['method'] = verbAction(conf.get('action'))
 
@@ -122,14 +129,15 @@ class Fork(Base):
             Metodo para registrar la configuracion del metodo
             que se ejecutara.
         """
-        if not conf is None:
+        if conf is not None:
             # Asignar los paso a repetir.
             for item in conf:
                 # Configuracion
                 conf_item = item.get('conf')
                 if not self.existService(conf_item):
+                    Version = conf_item.get('Version')
                     # Validar el formato del ID
-                    if conf_item.get('App') == 'appcoppel' and conf_item.get('Version') == 'v1':
+                    if conf_item.get('App') == 'appcoppel' and Version == 'v1':
                         self.___conf_forks.update(
                             {conf_item.get('Name'): item})
                     else:
@@ -150,7 +158,9 @@ class Fork(Base):
             previamente registrado.
         """
         for item in self.___forks:
-            if item.get('App') == conf.get('App') and item.get('Name') == conf.get('Name'):
+            APP = item.get('App')
+            NAME = item.get('Name')
+            if APP == conf.get('App') and NAME == conf.get('Name'):
                 return True
 
         return False
@@ -166,7 +176,8 @@ class Fork(Base):
         if conf.get('fnc_call', None):
             # Recuperar la funcion
             fnc_call = conf.get('fnc_call')
-            # Ejecutar la funcion los parametros de los datos nuevos y originales
+            # Ejecutar la funcion los parametros de
+            # los datos nuevos y originales
             resp = fnc_call(dataDefault, response)
             # Validar que sea un diccionario
             if isinstance(resp, dict):
@@ -228,7 +239,8 @@ class Fork(Base):
 
     def isError(self, data):
         """
-            Metodo para asergurar si ocurrio un error al momento de consumir el servicio
+            Metodo para asergurar si ocurrio un error al
+            momento de consumir el servicio
         """
         r = getItemBy('response', data)
         rp = getItemBy('response.data.response', data)
