@@ -1,8 +1,6 @@
-import traceback
-from opentracing.ext import tags as ext_tags
 from .Base import Base
 from .ErrorMs import ErrorMs
-from .Util import getItemBy
+
 
 class Worker(Base):
     """
@@ -18,11 +16,14 @@ class Worker(Base):
             @params resquest peticion de datos
             @params fnc Funcion a ejecutar
         """
-        # Parametros
-        paramsInject = self.getParams(span, request, params)
-
-        # Ejecutar la funciona final
-        RESP = fnc(**paramsInject)
-        # Regresar la respuesta con el formato correcto
-        return self.formatResponse(request, RESP)
+        try:
+            # Parametros
+            paramsInject = self.getParams(request, params)
 
+            # Ejecutar la funciona final
+            RESP = fnc(**paramsInject)
+            # Regresar la respuesta con el formato correcto
+            return self.formatResponse(request, RESP)
+        except ErrorMs as err:
+            # Retornar el error
+            return self.formatResponse(request, None, err.errorCode)
