@@ -25,7 +25,7 @@ def Loggs(name, logsAll=True):
             StreamHandler(sys.stdout).push_application()
             return Logger(name)
         elif logsAll:
-            coloredlogs.install(level='DEBUG', logger=logger)
+            coloredlogs.install()  # logger=logger
         else:
             coloredlogs.install()
         return logger
