@@ -185,7 +185,7 @@ class Microservices(BaseClass, ABC):
                         if healthcheck() and smoketest():
                             code = 200
                             message_parts.append("OK")
-                    except:
+                    except Exception:
                         code = 500
 
                     if code < 100:
@@ -320,26 +320,35 @@ class Microservices(BaseClass, ABC):
             _data_.update({'data': msg.get('data', {})})
             self.logs.info('ENTRADA {}'.format(json.dumps(_data_)))
         elif self.__OPT.Debug:
-            self.logs.info("\n ENTRADA: {} \n METODO: {} \n HEADERS: {} \n DATA: {}".format(
-                meta.get('owner'),
-                meta.get('method'),
-                json.dumps(msg.get('headers', {})),
-                msg.get('data', {})
-            ))
+            self.logs.info(
+                "\n ENTRADA: {}\n METODO: {}\n HEADERS: {}\n DATA: {}".format(
+                    meta.get('owner'),
+                    meta.get('method'),
+                    json.dumps(msg.get('headers', {})),
+                    msg.get('data', {})
+                ))
 
         try:
-            if msg['metadata']['time'].index('Z') > -1:
-                date = datetime.datetime.strptime(
-                    msg['metadata']['time'], '%Y-%m-%dT%H:%M:%SZ')
-                currDate = datetime.datetime.utcnow()
-                elapsedTime = currDate - date
+            TIME = msg['metadata']['time']
+            DATE = None
+            IS_Z = TIME.find('Z') > -1
+            currDate = datetime.datetime.utcnow()
+
+            if IS_Z:
+                DATE = datetime.datetime.strptime(
+                    TIME,
+                    '%Y-%m-%dT%H:%M:%SZ'
+                )
+
+                elapsedTime = currDate - DATE
                 diff = divmod(elapsedTime.total_seconds(), 60)[0]
                 if diff >= 5:
                     # print('EXIT TIME : ', msg['metadata']['time'], ' ', diff)
                     pass
-        except:
+
+        except Exception as e:
             self.logs.warn(
-                'Ocurrior un error al momento de procesar el tiempo del mensaje')
+                'Error al momento de procesar el tiempo del mensaje', e)
 
         # Procesar el mensaje
         try:
@@ -347,7 +356,10 @@ class Microservices(BaseClass, ABC):
         except Exception as identifier:
             # No fue posible recuperar una accion para el evento
             self.logs.error(
-                'No fue posible recuperar una accion para el evento {}'.format(identifier))
+                'No fue posible recuperar una accion para el evento {}'.format(
+                    identifier
+                )
+            )
 
         # Validar que exista
         try:
@@ -395,13 +407,16 @@ class Microservices(BaseClass, ABC):
             id_route_nats = getItemBy('response.uuid', RESP)
 
             if not msg['metadata']['mtype'] == 'WITHOUT_RESPONSE':
+                RESPONSE = RESP.get('response', {})
+                ERROR_CODE = RESP.get('errorCode')
+                ERROR_WORKER = RESP.get('errorWorker', None)
                 # Enviar la respuesta
                 self.__response(
-                    RESP.get('response', {}),
-                    RESP.get('errorCode'),
+                    RESPONSE,
+                    ERROR_CODE,
                     span=span,
                     nats_route=id_route_nats,
-                    errorResp=RESP.get('errorWorker', None),
+                    errorResp=ERROR_WORKER,
                 )
 
         except ErrorMs as error:
@@ -430,7 +445,8 @@ class Microservices(BaseClass, ABC):
 
         span.finish()
 
-    def __response(self, data, errorCode, isSmokeTest=False, nats_route=None, span=None, errorResp=None):
+    def __response(self, data, errorCode, isSmokeTest=False,
+                   nats_route=None, span=None, errorResp=None):
         """
             Metodo para enviar la respuesta a kafka
         """
@@ -444,17 +460,23 @@ class Microservices(BaseClass, ABC):
         # Topico de respuesta
         TOPIC_RESP = None
 
+        # Codigo de error
+        errorCodeBk = 0
+
         # Comprobar si contiene un error heredado
-        if not errorResp is None:
+        if errorResp is not None:
             errorCode = errorResp.get('errorCode', -99)  # Error generico
 
         try:
             errorCodeBk = errorCode
             # Prevenir el paso de string como error
             errorCode = int(errorCode)
-        except:
+        except Exception:
             self.logs.error(
-                'Ocurrio une error al realizar el CAST del error code: {}'.format(errorCodeBk))
+                'Ocurrio une error al con el CAST del error code: {}'.format(
+                    errorCodeBk
+                )
+            )
             errorCode = -99
 
         # Validar si ocurrio un error
@@ -526,7 +548,7 @@ class Microservices(BaseClass, ABC):
                 # Agregar
                 dataResponse['metadata'].update({'callbacks': []})
                 # Validar que sea NATS
-                if not nats_route is None or len(nats_route) > 0:
+                if nats_route is not None or len(nats_route) > 0:
                     # Agregar el Nats_UUID
                     dataResponse['metadata']['callbacks'].append({
                         "method": 'ENDPOINT',
@@ -584,23 +606,33 @@ class Microservices(BaseClass, ABC):
             else:
                 pass
 
+            original_method = dataResponse['metadata'].get(
+                'original_method', None)
+
             # Eliminamos elemento (Este es agregado cuando es una bifurcacion)
-            if not dataResponse['metadata'].get('original_method', None) is None:
+            if original_method is not None:
                 del dataResponse['metadata']['original_method']
             else:
                 pass
 
         # Ver si es utilizado Nats
         if nats_route is None:
+            OWNER = dataResponse['metadata']['owner']
             # Topico de respuesta
             TOPIC_RESP = TOPIC_RESP if TOPIC_RESP else "respuesta_{}".format(
-                dataResponse['metadata']['owner'])
+                OWNER)
         else:
-            # Comprobar si corresponde a un topico de servicio o sistema
-            is_topic = re.search(
-                "[a-zA-Z0-9]{1,}[_.]{1}[a-zA-Z0-9]{1,}[_.]{1}.*", TOPIC_RESP)
-            # Asignar el id de ruta que proviene del reply
-            TOPIC_RESP = TOPIC_RESP if is_topic else nats_route
+            # Validar si existe un topico seleccionado
+            if TOPIC_RESP is None:
+                TOPIC_RESP = nats_route
+            else:
+                # Comprobar si corresponde a un topico de servicio o sistema
+                is_topic = re.search(
+                    "[a-zA-Z0-9]{1,}[_.]{1}[a-zA-Z0-9]{1,}[_.]{1}.*",
+                    TOPIC_RESP
+                )
+                # Asignar el id de ruta que proviene del reply
+                TOPIC_RESP = TOPIC_RESP if is_topic else nats_route
 
         # Consultar quien es el callback
         cllb = getItemBy('metadata.callback', dataResponse)
@@ -634,6 +666,8 @@ class Microservices(BaseClass, ABC):
             del Resp['metadata']['metadata_inicial']
             del Resp['metadata']['data_inicial']
 
+        id_transaction = dataResponse['metadata']['id_transaction']
+
         # Revisar si es un smoketest
         if isSmokeTest:
             # respuesta generica
@@ -649,7 +683,7 @@ class Microservices(BaseClass, ABC):
                             }
                         },
                         "meta": {
-                            "id_transaction": dataResponse['metadata']['id_transaction'],
+                            "id_transaction": id_transaction,
                             "status": 'ERROR' if errorCode < 0 or errorCode > 0 else 'SUCCESS'
                         }
                     }
@@ -658,6 +692,9 @@ class Microservices(BaseClass, ABC):
 
         span.log_kv({'event': 'output', 'response': Resp['response']})
 
+        if nats_route is not None:
+            Resp.update({"uuid": nats_route})
+
         # Validar si es modeo DEBUG
         if self.__OPT.Debug and self.__fluentd_logs:
             self.logs.info("SALIDA [{}]".format(TOPIC_RESP), Resp)
@@ -678,7 +715,7 @@ class Microservices(BaseClass, ABC):
                 return self.__ERRORS.get(str(id_error))
             else:
                 return self.__ERRORS.get('-99')
-        except:
+        except Exception:
             self.logs.error(
                 'Ocurrio un excepcion al recuperar los datos del error')
             return 'Ocurrio un error generico'
